@@ -549,6 +549,29 @@ def sync_tools(server_script: str,
     return asyncio.run(quick_tools(server_script, alias))
 
 
+def sync_list_tools(server_script: str,
+                   alias: Optional[str] = None,
+                   force_refresh: bool = False,
+                   role: Optional[str] = None) -> List[Tool]:
+    """
+    同步版本的获取工具详细信息
+    
+    Args:
+        server_script: 服务器脚本路径
+        alias: 服务器别名（可选）
+        force_refresh: 是否强制刷新缓存
+        role: 角色过滤（可选）
+        
+    Returns:
+        List[Tool]: 工具对象列表
+    """
+    async def _get_tools():
+        async with SimpleClient(server_script, alias) as client:
+            return await client.list_tools(force_refresh=force_refresh, role=role)
+    
+    return asyncio.run(_get_tools())
+
+
 def sync_tool_params(server_script: str,
                     tool_name: str,
                     alias: Optional[str] = None) -> Dict[str, Any]:
