@@ -659,6 +659,13 @@ class BaseMCPServer(ABC):
     async def startup(self) -> None:
         """服务器启动时调用"""
         if not self._initialized:
+            # 对于 EnhancedMCPServer，检查是否需要延迟配置加载
+            if (hasattr(self, '_config_loaded') and not self._config_loaded and 
+                (not hasattr(self, 'server_config_manager') or self.server_config_manager is None)):
+                print(f"🔍 检测到延迟配置加载，创建默认配置管理器", file=sys.stderr)
+                self._auto_load_config()
+                self._config_loaded = True
+            
             # 检查是否有外部设置的配置管理器，如果有则重新加载配置
             if hasattr(self, 'server_config_manager') and self.server_config_manager is not None:
                 try:
@@ -706,7 +713,7 @@ class EnhancedMCPServer(BaseMCPServer):
         from .decorators import AnnotatedDecorators
         self.decorators = AnnotatedDecorators(self)
         
-        # 如果提供了配置管理器，使用它；否则自动加载配置
+        # 如果提供了配置管理器，使用它；否则延迟配置加载
         if config_manager:
             self.server_config_manager = config_manager
             # 尝试加载配置
@@ -718,8 +725,10 @@ class EnhancedMCPServer(BaseMCPServer):
                 self._apply_default_config()
                 self.logger.info(f"Applied default configuration for server '{self.name}' (no config file found)")
         else:
-            # 自动加载配置
-            self._auto_load_config()
+            # 延迟配置加载，等待外部设置配置管理器
+            # 这样可以避免在没有端口信息时创建错误的配置管理器
+            self.server_config_manager = None
+            self._config_loaded = False
 
     def register_tool(self, name: str, description: str, input_schema: Dict[str, Any],
                       handler: Callable, chunk_size: int = 100,
