@@ -33,6 +33,14 @@ class ServerConfig:
         valid_fields = set(inspect.signature(cls).parameters.keys())
         filtered_data = {k: v for k, v in data.items() if k in valid_fields}
         return cls(**filtered_data)
+    
+    def update_from_dict(self, data: Dict[str, Any]) -> None:
+        """从字典更新配置"""
+        import inspect
+        valid_fields = set(inspect.signature(self.__class__).parameters.keys())
+        for key, value in data.items():
+            if key in valid_fields and hasattr(self, key):
+                setattr(self, key, value)
 
 
 @dataclass
@@ -52,8 +60,8 @@ class ServerParameter:
 class ConfigManager:
     """配置管理器"""
 
-    def __init__(self, config_name: str = "server_config.json"):
-        self.config_dir = get_config_dir()
+    def __init__(self, config_name: str = "server_config.json", custom_config_dir: Optional[str] = None):
+        self.config_dir = get_config_dir(custom_config_dir)
         self.config_dir.mkdir(parents=True, exist_ok=True)
         self.config_file = self.config_dir / config_name
         self.logger = logging.getLogger(f"{__name__}.ConfigManager")
@@ -95,8 +103,8 @@ class ConfigManager:
 class ServerConfigManager:
     """服务器配置管理器"""
 
-    def __init__(self, server_name: str, port: Optional[int] = None, alias: Optional[str] = None):
-        self.config_dir = get_config_dir()
+    def __init__(self, server_name: str, port: Optional[int] = None, alias: Optional[str] = None, custom_config_dir: Optional[str] = None):
+        self.config_dir = get_config_dir(custom_config_dir)
         self.config_dir.mkdir(parents=True, exist_ok=True)
         
         # 支持别名和端口号两种方式创建配置文件
@@ -218,19 +226,19 @@ class ServerConfigManager:
         }
     
     @classmethod
-    def create_for_port(cls, server_name: str, port: int) -> 'ServerConfigManager':
+    def create_for_port(cls, server_name: str, port: int, custom_config_dir: Optional[str] = None) -> 'ServerConfigManager':
         """为指定端口创建配置管理器"""
-        return cls(server_name, port=port)
+        return cls(server_name, port=port, custom_config_dir=custom_config_dir)
     
     @classmethod
-    def create_for_alias(cls, server_name: str, alias: str) -> 'ServerConfigManager':
+    def create_for_alias(cls, server_name: str, alias: str, custom_config_dir: Optional[str] = None) -> 'ServerConfigManager':
         """为指定别名创建配置管理器"""
-        return cls(server_name, alias=alias)
+        return cls(server_name, alias=alias, custom_config_dir=custom_config_dir)
     
     @classmethod
-    def create_default(cls, server_name: str) -> 'ServerConfigManager':
+    def create_default(cls, server_name: str, custom_config_dir: Optional[str] = None) -> 'ServerConfigManager':
         """创建默认配置管理器"""
-        return cls(server_name)
+        return cls(server_name, custom_config_dir=custom_config_dir)
 
 
 class ServerConfigAdapter:
@@ -262,6 +270,24 @@ class ServerConfigAdapter:
         self.save_config(config)
         return config
     
+    def load_server_config(self) -> Dict[str, Any]:
+        """直接加载配置字典，包含自定义字段"""
+        return self.server_config_manager.load_server_config()
+    
+    def save_server_config(self, config: Dict[str, Any]) -> bool:
+        """直接保存配置字典，包含自定义字段"""
+        return self.server_config_manager.save_server_config(config)
+    
+    def update_config(self, config_updates: Dict[str, Any]) -> bool:
+        """更新配置，保留现有的自定义字段"""
+        current_config = self.load_server_config()
+        current_config.update(config_updates)
+        return self.save_server_config(current_config)
+    
+    def config_exists(self) -> bool:
+        """检查配置文件是否存在"""
+        return self.server_config_manager.config_exists()
+    
     @property
     def config_file(self):
         """获取配置文件路径"""
