@@ -139,11 +139,20 @@ async def run_multi_transport_server(
             # 创建服务器配置
             config = create_server_config_from_args(args)
             
+            # 检查服务器实例是否已有配置管理器
+            existing_config_manager = getattr(server_instance, 'server_config_manager', None)
+            if existing_config_manager and hasattr(existing_config_manager, 'port'):
+                print(f"🔍 检测到现有配置管理器，端口: {existing_config_manager.port}", file=output_stream)
+                if existing_config_manager.port is None:
+                    print(f"⚠️  现有配置管理器端口为None，将替换为带端口信息的配置管理器", file=output_stream)
+            
             # 根据端口号创建专用的配置管理器
             config_manager = create_port_based_config_manager(server_name, config.port, args.get('config_dir'))
+            print(f"✅ 创建新配置管理器，端口: {config_manager.port}", file=output_stream)
             
             # 为服务器实例设置正确的配置管理器
             server_instance.server_config_manager = config_manager
+            print(f"📝 配置文件路径: {config_manager.config_file}", file=output_stream)
             
             # 检查是否存在该端口的配置文件，如果不存在则创建
             if not config_manager.config_exists():
@@ -315,7 +324,8 @@ def run_http_server_main(
     default_host: str = "localhost",
     required_dependencies: Optional[list] = None,
     custom_args: Optional[Dict[str, Any]] = None,
-    alias: Optional[str] = None
+    alias: Optional[str] = None,
+    config_dir: Optional[str] = None
 ) -> None:
     """仅HTTP服务器启动"""
     # 如果提供了别名，在框架内部创建配置管理器
@@ -331,6 +341,12 @@ def run_http_server_main(
         except Exception as e:
             print(f"⚠️ 别名配置管理器创建失败: {e}")
     
+    # 确保config_dir传递给custom_args
+    if config_dir:
+        if custom_args is None:
+            custom_args = {}
+        custom_args["config_dir"] = config_dir
+    
     run_multi_transport_server_main(
         server_instance=server_instance,
         transports=["http"],
@@ -424,14 +440,15 @@ def run_dual_server_main(
     default_host: str = "localhost",
     required_dependencies: Optional[list] = None,
     custom_args: Optional[Dict[str, Any]] = None,
-    alias: Optional[str] = None
+    alias: Optional[str] = None,
+    config_dir: Optional[str] = None
 ) -> None:
     """HTTP+stdio双传输服务器启动"""
     # 如果提供了别名，在框架内部创建配置管理器
     if alias:
         try:
             from .config import ServerConfigManager, ServerConfigAdapter
-            server_config_manager = ServerConfigManager.create_for_alias(server_name, alias)
+            server_config_manager = ServerConfigManager.create_for_alias(server_name, alias, custom_config_dir=config_dir)
             config_manager = ServerConfigAdapter(server_config_manager)
             if custom_args is None:
                 custom_args = {}
@@ -440,6 +457,12 @@ def run_dual_server_main(
         except Exception as e:
             print(f"⚠️ 别名配置管理器创建失败: {e}")
     
+    # 确保config_dir传递给custom_args
+    if config_dir:
+        if custom_args is None:
+            custom_args = {}
+        custom_args["config_dir"] = config_dir
+    
     run_multi_transport_server_main(
         server_instance=server_instance,
         transports=["both"],
