@@ -134,12 +134,12 @@ class SimpleLauncher:
                 config_dir=config_dir
             )
         elif mode == 'dual':
-            sys.argv = [sys.argv[0], "dual", str(port)]
+            sys.argv = [sys.argv[0], "--port", str(port)]
             if config_dir:
                 sys.argv.extend(['--config-dir', config_dir])
             run_dual_server_main(self.server_instance, default_port=port, server_name=server_name, alias=alias, config_dir=config_dir, custom_args=custom_args if custom_args else None)
         elif mode == 'http':
-            sys.argv = [sys.argv[0], "http", str(port)]
+            sys.argv = [sys.argv[0], "--port", str(port)]
             if config_dir:
                 sys.argv.extend(['--config-dir', config_dir])
             run_http_server_main(self.server_instance, default_port=port, server_name=server_name, alias=alias, config_dir=config_dir, custom_args=custom_args if custom_args else None)
