@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 """
 MCP stdio 服务器实现
-支持通过标准输入输出进行通信，包含流式传输支持
+支持通过标准输入输出进行通信，包含流式传输支持和配置管理
 """
 
 import asyncio
@@ -10,15 +10,17 @@ import logging
 import sys
 from typing import Dict, Any, Optional, AsyncGenerator
 from ..core.base import BaseMCPServer
+from ..core.config import ConfigManager
 
 logger = logging.getLogger(__name__)
 
 
 class MCPStdioServer:
-    """MCP stdio 服务器 - 支持流式传输"""
+    """MCP stdio 服务器 - 支持流式传输和配置管理"""
     
-    def __init__(self, mcp_server: BaseMCPServer):
+    def __init__(self, mcp_server: BaseMCPServer, config_manager: Optional[ConfigManager] = None):
         self.mcp_server = mcp_server
+        self.config_manager = config_manager
         self.logger = logging.getLogger(f"{__name__}.MCPStdioServer")
         self._running = False
         self._stream_tasks = set()  # 跟踪流式任务
@@ -91,9 +93,9 @@ class MCPStdioServer:
         
     async def _read_line(self) -> Optional[str]:
         """从stdin异步读取一行"""
-        loop = asyncio.get_event_loop()
         try:
-            # 在线程池中执行阻塞的readline操作
+            # 使用线程池执行阻塞的readline操作
+            loop = asyncio.get_event_loop()
             line = await loop.run_in_executor(None, sys.stdin.readline)
             return line if line else None
         except Exception as e:
@@ -142,13 +144,24 @@ class MCPStdioServer:
             if method == "initialize":
                 result = await self._handle_initialize(params)
             elif method == "tools/list":
-                result = await self._handle_tools_list()
+                result = await self._handle_tools_list(params)
             elif method == "tools/call":
                 result = await self._handle_tool_call(params)
             elif method == "resources/list":
                 result = await self._handle_resources_list()
             elif method == "resources/read":
                 result = await self._handle_resource_read(params)
+            # 配置管理相关方法
+            elif method == "config/get":
+                result = await self._handle_config_get(params)
+            elif method == "config/update":
+                result = await self._handle_config_update(params)
+            elif method == "config/reset":
+                result = await self._handle_config_reset(params)
+            elif method == "server/parameters":
+                result = await self._handle_server_parameters(params)
+            elif method == "server/configure":
+                result = await self._handle_server_configure(params)
             else:
                 return {
                     "jsonrpc": "2.0",
@@ -359,11 +372,29 @@ class MCPStdioServer:
         }
         await self._send_response(message)
     
-    async def _handle_tools_list(self) -> Dict[str, Any]:
-        """处理工具列表请求"""
-        return {
-            "tools": self.mcp_server.tools
-        }
+    async def _handle_tools_list(self, params: Dict[str, Any]) -> Dict[str, Any]:
+        """处理工具列表请求，支持 role 参数过滤"""
+        role = params.get("role") if isinstance(params, dict) else None
+        if role:
+            filtered_tools = []
+            for tool in self.mcp_server.tools:
+                # 新格式：roles 为列表
+                if 'roles' in tool and tool['roles']:
+                    if role in tool['roles']:
+                        filtered_tools.append(tool)
+                # 旧格式：role 为单值
+                elif tool.get('role') == role:
+                    filtered_tools.append(tool)
+                # 通用工具：没有角色限制
+                elif tool.get('role') is None and tool.get('roles') is None:
+                    filtered_tools.append(tool)
+            return {
+                "tools": filtered_tools
+            }
+        else:
+            return {
+                "tools": self.mcp_server.tools
+            }
     
     async def _handle_tool_call(self, params: Dict[str, Any]) -> Dict[str, Any]:
         """处理工具调用请求"""
@@ -409,4 +440,139 @@ class MCPStdioServer:
                     "text": str(result)
                 }
             ]
-        }
\ No newline at end of file
+        }
+    
+    async def _handle_config_get(self, params: Dict[str, Any]) -> Dict[str, Any]:
+        """处理获取配置请求"""
+        if not self.config_manager:
+            return {
+                "error": "Configuration manager not available"
+            }
+        
+        try:
+            # 如果配置管理器支持直接字典操作，使用它来获取包含自定义字段的完整配置
+            if hasattr(self.config_manager, 'load_server_config'):
+                config_dict = self.config_manager.load_server_config()
+                return {
+                    "config": config_dict
+                }
+            else:
+                # 回退到原有的ServerConfig对象方式
+                config = self.config_manager.load_config()
+                return {
+                    "config": config.to_dict() if hasattr(config, 'to_dict') else config.__dict__
+                }
+        except Exception as e:
+            self.logger.error(f"Failed to get config: {e}")
+            return {
+                "error": f"Failed to get config: {e}"
+            }
+    
+    async def _handle_config_update(self, params: Dict[str, Any]) -> Dict[str, Any]:
+        """处理更新配置请求"""
+        if not self.config_manager:
+            return {
+                "error": "Configuration manager not available"
+            }
+        
+        try:
+            config_data = params.get('config', {})
+            
+            # 如果配置管理器支持直接字典操作，使用它来保留自定义字段
+            if hasattr(self.config_manager, 'update_config'):
+                success = self.config_manager.update_config(config_data)
+            else:
+                # 回退到原有的ServerConfig对象方式
+                current_config = self.config_manager.load_config()
+                
+                # 更新配置
+                if hasattr(current_config, 'update_from_dict'):
+                    current_config.update_from_dict(config_data)
+                else:
+                    for key, value in config_data.items():
+                        if hasattr(current_config, key):
+                            setattr(current_config, key, value)
+                
+                # 保存配置
+                success = self.config_manager.save_config(current_config)
+            
+            if success:
+                return {
+                    "success": True,
+                    "message": "Configuration updated successfully"
+                }
+            else:
+                return {
+                    "error": "Failed to save configuration"
+                }
+        except Exception as e:
+            self.logger.error(f"Failed to update config: {e}")
+            return {
+                "error": f"Failed to update config: {e}"
+            }
+    
+    async def _handle_config_reset(self, params: Dict[str, Any]) -> Dict[str, Any]:
+        """处理重置配置请求"""
+        if not self.config_manager:
+            return {
+                "error": "Configuration manager not available"
+            }
+        
+        try:
+            config = self.config_manager.reset_config()
+            return {
+                "success": True,
+                "message": "Configuration reset successfully",
+                "config": config.to_dict() if hasattr(config, 'to_dict') else config.__dict__
+            }
+        except Exception as e:
+            self.logger.error(f"Failed to reset config: {e}")
+            return {
+                "error": f"Failed to reset config: {e}"
+            }
+    
+    async def _handle_server_parameters(self, params: Dict[str, Any]) -> Dict[str, Any]:
+        """处理获取服务器参数定义请求"""
+        try:
+            parameters = self.mcp_server.get_server_parameters()
+            return {
+                "success": True,
+                "parameters": [
+                    {
+                        'name': param.name,
+                        'display_name': param.display_name,
+                        'description': param.description,
+                        'type': param.param_type,
+                        'default_value': param.default_value,
+                        'required': param.required,
+                        'options': param.options,
+                        'placeholder': param.placeholder,
+                        'validation_pattern': param.validation_pattern
+                    } for param in parameters
+                ]
+            }
+        except Exception as e:
+            self.logger.error(f"Failed to get server parameters: {e}")
+            return {
+                "error": f"Failed to get server parameters: {e}"
+            }
+    
+    async def _handle_server_configure(self, params: Dict[str, Any]) -> Dict[str, Any]:
+        """处理配置服务器参数请求"""
+        try:
+            config = params.get('config', {})
+            
+            if self.mcp_server.configure_server(config):
+                return {
+                    "success": True,
+                    "message": "Server configured successfully"
+                }
+            else:
+                return {
+                    "error": "Failed to configure server"
+                }
+        except Exception as e:
+            self.logger.error(f"Failed to configure server: {e}")
+            return {
+                "error": f"Failed to configure server: {e}"
+            }
\ No newline at end of file
